@@ -2,7 +2,7 @@ package Module::Build::Platform::Unix;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.4204';
+$VERSION = '0.4206';
 $VERSION = eval $VERSION;
 use Module::Build::Base;
 
@@ -43,8 +43,8 @@ sub _detildefy {
   my ($self, $value) = @_;
   $value =~ s[^~([^/]+)?(?=/|$)]   # tilde with optional username
     [$1 ?
-     ((getpwnam $1)[7] || "~$1") :
-     ($ENV{HOME} || (getpwuid $>)[7])
+     (eval{(getpwnam $1)[7]} || "~$1") :
+     ($ENV{HOME} || eval{(getpwuid $>)[7]} || glob("~"))
     ]ex;
   return $value;
 }
